@@ -58,9 +58,14 @@ def get_token_parent_span(
             list: List of indices of child tokens (indices are the locations of
                 the children within the parent Doc object).
         """
-        indices = [token.i for token in head.children]
+        children = [
+            child
+            for child in head.children
+            if child.dep_ != "cc" and child.dep_ != "conj"
+        ]
+        indices = [child.i for child in children]
         indices.append(head.i)
-        for child in head.children:
+        for child in children:
             indices.extend(get_children_indices(child))
         indices.sort()
         return indices
@@ -74,7 +79,9 @@ def get_token_parent_span(
     else:
         span = doc[first : last + 1]
     if len(span) < min_length and token.head != token.head.head:
-        span = get_token_parent_span(token.head, min_length=min_length)
+        new_span = get_token_parent_span(token.head, min_length=min_length)
+        if token in new_span:
+            span = new_span
     return span
 
 
@@ -104,7 +111,7 @@ def set_doc_contains_aspect(
     set_extension("contains_aspect", default_val=False)
 
     for token in doc:
-        if token.lemma_.lower() in base_keywords:
+        if token.lemma_ in base_keywords or token.lemma_.lower() in base_keywords:
             doc._.contains_aspect = True
             break
 
@@ -143,7 +150,7 @@ def set_doc_aspects(
                 if aspect in aspects_contained:
                     continue
                 keywords = base_aspects[aspect]
-                if token.lemma_.lower() in keywords:
+                if token.lemma_ in keywords or token.lemma_.lower() in keywords:
                     aspects_contained.append(aspect)
         doc._.aspects = aspects_contained
     return doc
@@ -175,7 +182,7 @@ def set_doc_keywords(
     if doc._.contains_aspect == True:
         keywords = []
         for token in doc:
-            if token.lemma_.lower() in base_keywords:
+            if token.lemma_ in base_keywords or token.lemma_.lower() in base_keywords:
                 keywords.append(token)
         doc._.keywords = keywords
     return doc
@@ -216,7 +223,10 @@ def set_token_aspects(
     for doc_keyword in doc._.keywords:
         for aspect in base_aspects:
             for keyword in base_aspects[aspect]:
-                if doc_keyword.lemma_.lower() == keyword:
+                if (
+                    doc_keyword.lemma_ == keyword
+                    or doc_keyword.lemma_.lower() == keyword
+                ):
                     doc_keyword._.aspect = aspect
                 continue
             if doc_keyword._.aspect != None:
@@ -415,10 +425,11 @@ def set_anonymized(
     anonymized = doc.text
 
     for token in doc:
+        if token.ent_type_ == "":
+            continue
         start = token.idx
         stop = token.idx + len(token)
-        if token.ent_type_ != "":
-            anonymized = anonymized[:start] + ("*" * len(token)) + anonymized[stop:]
+        anonymized = anonymized[:start] + ("*" * len(token)) + anonymized[stop:]
 
     doc._.anonymized = anonymized
 
